Learn R Programming

climodr (version 1.0.0)

envi.create: Create climodr environment

Description

Creates an environment climodr will use during the calculation process. A list is returned with all paths to all folders. After creating the environment, all necessary data should be stored into the depending Input sub-folders. There is also an additional temp-folder, where temporary data is stored, which can be deleted after not being used anymore.

Usage

envi.create(proj_path = tempdir(), memfrac = NULL, ...)

Value

list. Contains all paths to each folder in the project directory. Necessary for climodr to operate its functions.

Arguments

proj_path

character. Path to project directory. Climodr will work exclusively in this folder and create all project folders in here.

memfrac

numeric. Value between 0 and 0.9. The fraction of RAM that may be used by the terra package

...

arguments passed down from other functions.

Examples

Run this code
# create climodr environment and allow terra-functions to use 70% of RAM
envrmt <- envi.create(proj_path = tempdir(),
                      memfrac = 0.7)

Run the code above in your browser using DataLab