Creates an environment climodr will use during the calculation process. A list is returned with all paths to all folders.
After creating the environment, all necessary data should be stored into the depending Input sub-folders.
There is also an additional temp-folder, where temporary data is stored, which can be deleted after not being used anymore.